import { useState, useEffect, memo } from "react";
import { createScrollOptimizer } from "@/utils/performance";
import { Button } from "@/components/ui/button";
import { Phone, Menu, X } from "lucide-react";
import { SiGoogle, SiInstagram } from "react-icons/si";
import OptimizedImage from "@/components/optimized-image";
import logoPath from "@assets/Color logo with background.png";

function Navigation() {
  const [isScrolled, setIsScrolled] = useState(false);
  const [isMobileMenuOpen, setIsMobileMenuOpen] = useState(false);

  useEffect(() => {
    const scrollOptimizer = createScrollOptimizer();
    
    const handleScroll = () => {
      scrollOptimizer(() => {
        setIsScrolled(window.scrollY > 100);
      });
    };

    window.addEventListener("scroll", handleScroll, { passive: true });
    return () => window.removeEventListener("scroll", handleScroll);
  }, []);

  const scrollToSection = (sectionId: string) => {
    const element = document.getElementById(sectionId);
    if (element) {
      const navHeight = 112; // Updated for h-28 header (28 * 4px = 112px)
      const elementPosition = element.offsetTop - navHeight;
      window.scrollTo({
        top: elementPosition,
        behavior: "smooth",
      });
    }
    setIsMobileMenuOpen(false);
  };

  return (
    <header className={`fixed top-0 w-full z-50 transition-all duration-300 ${
      isScrolled ? "bg-white shadow-lg" : "bg-white shadow-sm"
    }`}>
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
        <div className="flex justify-between items-center h-28">
          <div className="flex items-center space-x-3">
            <OptimizedImage 
              src={logoPath} 
              alt="Isle of Wight Handymen Logo" 
              className="h-32 w-auto object-contain"
              priority={true}
            />
          </div>
          
          <nav className="hidden md:flex space-x-8">
            <button
              onClick={() => scrollToSection("services")}
              className="text-gray-700 hover:text-primary transition-colors font-medium"
            >
              Services
            </button>
            <button
              onClick={() => scrollToSection("gallery")}
              className="text-gray-700 hover:text-primary transition-colors font-medium"
            >
              Our Work
            </button>
            <button
              onClick={() => scrollToSection("contact")}
              className="text-gray-700 hover:text-primary transition-colors font-medium"
            >
              Contact
            </button>
          </nav>
          
          <div className="flex items-center space-x-4">
            {/* Social Media Icons */}
            <div className="hidden sm:flex items-center space-x-2">
              <a 
                href="https://www.google.com/maps/place/Isle+of+Wight+Handymen/@50.5868577,-1.2348179,14z/data=!4m6!3m5!1s0x4874898564732be7:0xeaa41f08dd928b33!8m2!3d50.5934256!4d-1.210509!16s%2Fg%2F11tnh_thms?entry=ttu&g_ep=EgoyMDI1MDQwMi4xIKXMDSoASAFQAw%3D%3D" 
                target="_blank" 
                rel="noopener noreferrer"
                className="flex items-center justify-center w-10 h-10 bg-red-600 hover:bg-red-700 text-white rounded-full transition-colors shadow-sm"
                aria-label="Find us on Google Business"
              >
                <SiGoogle className="h-5 w-5" />
              </a>
              <a 
                href="https://www.instagram.com/isle_of_wight_handy_men/" 
                target="_blank" 
                rel="noopener noreferrer"
                className="flex items-center justify-center w-10 h-10 bg-gradient-to-r from-purple-500 to-pink-500 hover:from-purple-600 hover:to-pink-600 text-white rounded-full transition-all shadow-sm"
                aria-label="Follow us on Instagram"
              >
                <SiInstagram className="h-5 w-5" />
              </a>
            </div>
            
            <a href="tel:07702471569" className="hidden sm:block">
              <Button className="bg-secondary hover:bg-yellow-500 text-primary font-semibold">
                <Phone className="mr-2 h-4 w-4" />
                Call Now
              </Button>
            </a>
            
            <button
              className="md:hidden"
              onClick={() => setIsMobileMenuOpen(!isMobileMenuOpen)}
            >
              {isMobileMenuOpen ? <X className="h-6 w-6" /> : <Menu className="h-6 w-6" />}
            </button>
          </div>
        </div>
        
        {/* Mobile Menu */}
        {isMobileMenuOpen && (
          <div className="md:hidden border-t border-gray-200 py-4">
            <div className="flex flex-col space-y-4">
              <button
                onClick={() => scrollToSection("services")}
                className="text-gray-700 hover:text-primary transition-colors font-medium text-left"
              >
                Services
              </button>
              <button
                onClick={() => scrollToSection("gallery")}
                className="text-gray-700 hover:text-primary transition-colors font-medium text-left"
              >
                Our Work
              </button>
              <button
                onClick={() => scrollToSection("contact")}
                className="text-gray-700 hover:text-primary transition-colors font-medium text-left"
              >
                Contact
              </button>
              
              {/* Social Media Links for Mobile */}
              <div className="flex items-center space-x-3 pt-2">
                <a 
                  href="https://www.google.com/maps/place/Isle+of+Wight+Handymen/@50.5868577,-1.2348179,14z/data=!4m6!3m5!1s0x4874898564732be7:0xeaa41f08dd928b33!8m2!3d50.5934256!4d-1.210509!16s%2Fg%2F11tnh_thms?entry=ttu&g_ep=EgoyMDI1MDQwMi4xIKXMDSoASAFQAw%3D%3D" 
                  target="_blank" 
                  rel="noopener noreferrer"
                  className="flex items-center justify-center w-12 h-12 bg-red-600 hover:bg-red-700 text-white rounded-full transition-colors shadow-sm"
                  aria-label="Find us on Google Business"
                >
                  <SiGoogle className="h-6 w-6" />
                </a>
                <a 
                  href="https://www.instagram.com/isle_of_wight_handy_men/" 
                  target="_blank" 
                  rel="noopener noreferrer"
                  className="flex items-center justify-center w-12 h-12 bg-gradient-to-r from-purple-500 to-pink-500 hover:from-purple-600 hover:to-pink-600 text-white rounded-full transition-all shadow-sm"
                  aria-label="Follow us on Instagram"
                >
                  <SiInstagram className="h-6 w-6" />
                </a>
              </div>
              
              <a href="tel:07702471569" className="w-full">
                <Button className="w-full bg-secondary hover:bg-yellow-500 text-primary font-semibold">
                  <Phone className="mr-2 h-4 w-4" />
                  Call Now
                </Button>
              </a>
            </div>
          </div>
        )}
      </div>
    </header>
  );
}

export default memo(Navigation);
